<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="vi">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Ứng dụng Proxy  </translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Dạng Ủy quyền</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Địa chỉ IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Cổng</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Tên người dùng</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Không bắt buộc</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mật mã</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Chọn &quot;Sử dụng proxy&quot; trong menu ngữ cảnh ứng dụng trong Trình khởi chạy sau khi được định cấu hình</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Hủy</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Lưu</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Địa chỉ IP sai</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Port không đúng</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Ngắt kết nối</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Xóa</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Hủy</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Lưu</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Đang kết nối</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Ngắt kết nối</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Bạn có chắc chắn muốn xóa cấu hình này?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Kết nối Có dây: %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Điểm truy cập</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Kết nối Không dây: %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Kết nối PPPoE: %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>VPN Mới</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Dạng VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>Mở VPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>Mở Kết nối</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Xuất</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Mạng</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Ứng dụng Proxy  </translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Kích hoạt điểm truy cập</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Chi tiết mạng</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Ủy thác hệ thống</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Mạng kết nối dây</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Mạng không dây</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Wired Network Adapter</translation>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Thêm Kết nối Mạng</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Wireless Network Adapter</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Kết nối với mạng ẩn</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Tạo Kết nối PPPoE</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>Tình trạng VPN</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Tạo VPN</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Nhập VPN</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Dạng Ủy quyền</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL Cấu hình</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Địa chỉ IP</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>Cổng</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>Tên người dùng</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>Mật mã</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Điểm truy cập</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Tạo điểm truy cập</translation>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>Giao diện</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>Băng tần</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Cổng vào</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Đầu</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Mặt nạ mạng</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Tiền tố</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>Tốt độ</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Địa chỉ DNS không hợp lệ</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Not Bind</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Địa chỉ MAC thiết bị</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Địa chỉ MAC được nhân bản</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU tùy chỉnh</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Tổng quát</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>tên</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Tổng quát</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Tên người dùng đã được sử dụng</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>tên</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Tự động kết nối</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Điểm truy cập</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Thêm thiết lập</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Tạo điểm truy cập</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>Địa chỉ IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Cổng vào</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Địa chỉ IP sai</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Netmask không hợp lệ</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Cổng không hợp lệ</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Mặt nạ mạng</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Địa chỉ IP sai</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Cổng không hợp lệ</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Tiền tố</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Tự động</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Tự chỉnh</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Bỏ qua</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Địa chỉ IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Cổng vào</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Chỉ được áp dụng trong những tài nguyên tương ứng</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Phương pháp</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Mặt nạ mạng</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Tiền tố</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Địa chỉ IP sai</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Netmask không hợp lệ</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Cổng không hợp lệ</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Mạng</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Phương pháp</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Tự động</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Tự chỉnh</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Bỏ qua</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Chi tiết mạng</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Ủy thác hệ thống</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Ứng dụng Proxy  </translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Chi tiết mạng</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Mạng</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Đã ngắt</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Tự chỉnh</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Tự động</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Cấu hình bởi Quản lý mạng</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Kích hoạt điểm truy cập</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Tên người dùng</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Dịch vụ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mật mã</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Từ chối Xác thực EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Từ chối Xác thực PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Từ chối Xác thực CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Từ chối Xác thực MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Từ chối Xác thực MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Không có Nén Dữ liệu BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Không có Nén Dữ liệu Xả bớt</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Không có Nén Phần đầu TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Nén Vùng không có Giao thức</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Nén không có Địa chỉ/Kiểm soát</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Gởi các gói Lặp lại PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Sử dụng MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>MPPE 128-bit</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE trạng thái</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Tạo Kết nối PPPoE</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Ủy thác hệ thống</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Hủy</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Lưu</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Dạng Ủy quyền</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>Tự chỉnh</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Tự động</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Không bắt buộc</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Cổng</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Ủy quyền HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>Ủy quyền HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Ủy quyền FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS Proxy</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Bỏ qua những cấu hình ủy quyền cho những máy chủ và tên miền ở trên</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL Cấu hình</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Bảo mật</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS được tạo đường</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP được bảo vệ</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Lưu mật khẩu chỉ mình tài khoản này</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Lưu mật khẩu cho tất cả tài khoản</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Luôn hỏi</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Đã ngắt</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Ẩn danh</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Đã xác thực</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Cả hai</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Tự động</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Phiên bản 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Phiên bản 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Xác thực EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Danh tính</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd Options</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chìa khóa Cá nhân</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Xác nhận CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Xác nhận Người dùng</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>ID Ẩn danh</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Dự phòng</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Tập tin PAC</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Xác thực bên trong</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Phiên bản PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Pwd Cá nhân</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mật mã</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Mật khẩu không đúng</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Không</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Cá nhân</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Bảo mật</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Chìa khóa</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mật mã</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Đòi hỏi Bảo mật</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Mật khẩu không đúng</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Không</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Cá nhân</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Công ty</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Mã key chung</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Mở hệ thống</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Bảo mật</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Xác thực</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Chìa khóa</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mật mã</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Cao cấp</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Tùy chỉnh Cổng Vào</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Cổng Vào</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Tùy chỉnh Khoảng thời gian Thỏa thuận lại</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Khoảng thời gian Thỏa thuận lại</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Sử dụng nén dữ liệu LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Sử dụng kết nối TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Sử dụng thiết bị TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Tùy chỉnh Tạo Đường hầm MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Tùy chỉnh Kích thước Mảnh UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Kích thước Mảnh UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Hạn chế Tạo Đường hầm TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Xếp ngẫu nhiên Những Máy chủ Ở xa</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Cao cấp</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (mặc định)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>An toàn (mặc định)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Yếu</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Không</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T Khi Có sẵn (mặc định)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>Luôn luôn NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Đã ngắt</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>Nhóm DH 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>Nhóm DH 2 (mặc định)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>Nhóm DH 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Máy chủ (mặc định)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>Nhóm DH 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Vùng</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Nhà cung cấp</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Phiên bản</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Mã hóa</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Chế độ Truyền tải NAT</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Nhóm IKE DH</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Bí mật Chuyển tiếp</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Cổng cục bộ</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Vô hiệu hóa Phát hiện Máy ngang hàng Chết</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Kích hoạt IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Tên nhóm</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID nhóm</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Chìa khóa Chia sẻ trước</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Phase1 Algorithms</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Phase2 Algorithms</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Cổng không hợp lệ</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Cổng vào</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Xác nhận CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Ủy thác</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Cho phép Trojan Trang đầu Bảo mật Cisco</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Mã CSD</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Xác nhận Người dùng</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chìa khóa Cá nhân</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Sử dụng FSID cho Cụm mật khẩu Chìa khóa</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Cổng không hợp lệ</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Những chứng nhận (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mật mã</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Những chứng nhận với Mật mã (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Chìa khóa tĩnh</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Đã lưu</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Yêu cầu</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Không Cần</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Cổng vào</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Dạng xác thực</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Xác nhận CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Xác nhận Người dùng</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chìa khóa Cá nhân</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd Options</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Pwd Cá nhân</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Tên người dùng</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Hướng Chìa khóa tùy chỉnh</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Hướng chỉa khóa</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP xa</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP địa phương</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Tất cả Có hiệu lực (mặc định)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (ít an toàn hơn)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (an toàn nhất)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Từ chối Xác thực EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Từ chối Xác thực PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Từ chối Xác thực CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Từ chối Xác thực MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Từ chối Xác thực MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Không có Nén Dữ liệu BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Không có Nén Dữ liệu Xả bớt</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Không có Nén Phần đầu TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Nén Vùng không có Giao thức</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Nén không có Địa chỉ/Kiểm soát</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Gởi các gói Lặp lại PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Sử dụng MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Bảo mật</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE trạng thái</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>Tình trạng VPN</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Tạo VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Nhập VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Lỗi nhập</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Tệp lỗi</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Không Cần</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Dạng Ủy quyền</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP Máy chủ</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Cổng</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Lặp lại Mãi Khi Thất bại</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Tên người dùng</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mật mã</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>Tập tin CA</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Bỏ qua cảnh báo chứng chỉ</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Sử dụng tiện ích mở rộng tên máy chủ TLS</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>Bảo mật VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Mặc định</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Không</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Mật mã</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>Xác thực HMAC</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Cổng không hợp lệ</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Đã lưu</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Yêu cầu</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Không Cần</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Cổng vào</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Tên người dùng</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd Options</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mật mã</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Miền NT</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP Máy chủ</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Cổng</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Tên người dùng</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mật mã</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Cổng không hợp lệ</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chìa khóa Cá nhân</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>Chương trình SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Smart Card</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Chìa khóa Chia sẻ trước</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Cổng vào</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Xác nhận CA</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Dạng xác thực</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Xác nhận Người dùng</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Tên người dùng</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mật mã</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Yêu cầu một Địa chỉ IP Bên trong</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Gói UDP Bắt buộc</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Sử dụng Nén IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Kích hoạt đề xuất mật mã tùy chỉnh</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Xác thực VPN TLS</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Mặc định</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Máy người dùng</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Máy chủ</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Kết hợp đối tượng</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Dạng Chứng nhận từ xa</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Tập tin Chính</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Hướng Chìa khóa tùy chỉnh</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Hướng chỉa khóa</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Cổng không hợp lệ</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Đã lưu</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Yêu cầu</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Không Cần</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Cổng vào</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Tên người dùng</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd Options</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mật mã</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Tên nhóm</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Pwd nhóm</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Sử dụng Xác thực Kết hợp</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Tập tin CA</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Đầu tiên xin hãy gắn dây cáp mạng vào</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Wired Network Adapter</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Thêm Kết nối Mạng</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Lực chọn Thiết lập</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Wireless Network Adapter</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Đóng điểm truy cập</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Trước tiên hãy tắt điểm phát sóng nếu bạn muốn kết nối với mạng không dây</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Kết nối với mạng ẩn</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Not Bind</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Địa chỉ MAC thiết bị</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU tùy chỉnh</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>